pub enum OsError {
KernelReleaseNotFound,
KernelVersionNotFound,
}Variants
KernelReleaseNotFound
An error indicating that the kernel release was not found.
KernelVersionNotFound
An error indicating that the kernel version was not found.