pub enum Color {
Black,
Red,
Green,
Yellow,
Blue,
Magenta,
Cyan,
White,
}Expand description
Color defines supported color types and provides static functions
Examples
use gory::*;
print!("{} ", format!("\\e[1;{}m", Color::Red).red());
print!("{} ", "red".red());
println!();Variants
Implementations
Sourceimpl Color
impl Color
Sourcepub fn enabled() -> bool
pub fn enabled() -> bool
Is color enabled.
Determines if the environment has a tty attached and the TERM_COLOR environment
variable is either unset or is set to a truthy value i.e. not 0 and not some
case insensitive variation of false.
Examples
use gory::*;
println!("{:?}", Color::enabled());Trait Implementations
impl Copy for Color
impl Eq for Color
impl StructuralPartialEq for Color